#[repr(C)]pub struct PostMultiPythPullOracleUpdatesAtomic {
pub keeper: Pubkey,
pub pyth_solana_receiver: Pubkey,
pub guardian_set: Pubkey,
}Fields
keeper: Pubkeypyth_solana_receiver: Pubkeyguardian_set: PubkeyTrait Implementations
Sourceimpl AccountDeserialize for PostMultiPythPullOracleUpdatesAtomic
impl AccountDeserialize for PostMultiPythPullOracleUpdatesAtomic
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl BorshDeserialize for PostMultiPythPullOracleUpdatesAtomicwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for PostMultiPythPullOracleUpdatesAtomicwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for PostMultiPythPullOracleUpdatesAtomic
impl Clone for PostMultiPythPullOracleUpdatesAtomic
Sourcefn clone(&self) -> PostMultiPythPullOracleUpdatesAtomic
fn clone(&self) -> PostMultiPythPullOracleUpdatesAtomic
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PostMultiPythPullOracleUpdatesAtomic
Sourceimpl Default for PostMultiPythPullOracleUpdatesAtomic
impl Default for PostMultiPythPullOracleUpdatesAtomic
Sourcefn default() -> PostMultiPythPullOracleUpdatesAtomic
fn default() -> PostMultiPythPullOracleUpdatesAtomic
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PostMultiPythPullOracleUpdatesAtomic
impl<'de> Deserialize<'de> for PostMultiPythPullOracleUpdatesAtomic
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Discriminator for PostMultiPythPullOracleUpdatesAtomic
impl Discriminator for PostMultiPythPullOracleUpdatesAtomic
Sourceconst DISCRIMINATOR: &[u8]
const DISCRIMINATOR: &[u8]
Discriminator slice. Read more
impl Pod for PostMultiPythPullOracleUpdatesAtomic
Sourceimpl ToAccountMetas for PostMultiPythPullOracleUpdatesAtomic
impl ToAccountMetas for PostMultiPythPullOracleUpdatesAtomic
fn to_account_metas(&self) -> Vec<AccountMeta>
impl ZeroCopy for PostMultiPythPullOracleUpdatesAtomic