pub struct ModifyOrder {
pub order_id: Option<u32>,
pub modify_order_params: ModifyOrderParams,
}Fields
order_id: Option<u32>modify_order_params: ModifyOrderParamsTrait Implementations
Sourceimpl BorshDeserialize for ModifyOrder
impl BorshDeserialize for ModifyOrder
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ModifyOrder
impl BorshSerialize for ModifyOrder
Sourceimpl Clone for ModifyOrder
impl Clone for ModifyOrder
Sourcefn clone(&self) -> ModifyOrder
fn clone(&self) -> ModifyOrder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ModifyOrder
impl Default for ModifyOrder
Sourcefn default() -> ModifyOrder
fn default() -> ModifyOrder
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for ModifyOrder
impl Discriminator for ModifyOrder
Sourceconst DISCRIMINATOR: &[u8]
const DISCRIMINATOR: &[u8]
Discriminator slice. Read more