#[repr(C)]pub struct FeeStructure {
pub fee_tiers: [FeeTier; 10],
pub filler_reward_structure: OrderFillerRewardStructure,
pub referrer_reward_epoch_upper_bound: u64,
pub flat_filler_fee: u64,
}Fields
fee_tiers: [FeeTier; 10]filler_reward_structure: OrderFillerRewardStructurereferrer_reward_epoch_upper_bound: u64flat_filler_fee: u64Trait Implementations
Sourceimpl BorshDeserialize for FeeStructure
impl BorshDeserialize for FeeStructure
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for FeeStructurewhere
[FeeTier; 10]: BorshSerialize,
OrderFillerRewardStructure: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for FeeStructurewhere
[FeeTier; 10]: BorshSerialize,
OrderFillerRewardStructure: BorshSerialize,
u64: BorshSerialize,
Sourceimpl Clone for FeeStructure
impl Clone for FeeStructure
Sourcefn clone(&self) -> FeeStructure
fn clone(&self) -> FeeStructure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FeeStructure
Sourceimpl Debug for FeeStructure
impl Debug for FeeStructure
Sourceimpl Default for FeeStructure
impl Default for FeeStructure
Sourcefn default() -> FeeStructure
fn default() -> FeeStructure
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FeeStructure
impl<'de> Deserialize<'de> for FeeStructure
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FeeStructure
impl PartialEq for FeeStructure
Sourceimpl Serialize for FeeStructure
impl Serialize for FeeStructure
Sourceimpl Space for FeeStructure
impl Space for FeeStructure
const INIT_SPACE: usize
impl StructuralPartialEq for FeeStructure