#[repr(C)]pub struct PoolBalance {
pub scaled_balance: u128,
pub market_index: u16,
pub padding: [u8; 6],
}Fields
scaled_balance: u128market_index: u16padding: [u8; 6]Trait Implementations
Sourceimpl BorshDeserialize for PoolBalance
impl BorshDeserialize for PoolBalance
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PoolBalance
impl BorshSerialize for PoolBalance
Sourceimpl Clone for PoolBalance
impl Clone for PoolBalance
Sourcefn clone(&self) -> PoolBalance
fn clone(&self) -> PoolBalance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PoolBalance
Sourceimpl Debug for PoolBalance
impl Debug for PoolBalance
Sourceimpl Default for PoolBalance
impl Default for PoolBalance
Sourcefn default() -> PoolBalance
fn default() -> PoolBalance
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PoolBalance
impl<'de> Deserialize<'de> for PoolBalance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PoolBalance
impl PartialEq for PoolBalance
Sourceimpl Serialize for PoolBalance
impl Serialize for PoolBalance
Sourceimpl Space for PoolBalance
impl Space for PoolBalance
const INIT_SPACE: usize
impl StructuralPartialEq for PoolBalance